@@ -2,9 +2,11 @@ from abc import ABC
 from dataclasses import dataclass
 from typing import Any, Dict, Union, List, Type, Iterable
 
+import pydantic
+
 from pycurd.const import QUERY_OP_RELATION
 from pycurd.crud._core_crud import CoreCrud
-from pycurd.crud.query_result_row import QueryResultRow
+from pycurd.crud.query_result_row import QueryResultRow, QueryResultRowList
 from pycurd.error import PermissionException
 from pycurd.permission import RoleDefine, A
 from pycurd.query import QueryInfo, QueryConditions, ConditionExpr, QueryJoinInfo, ConditionLogicExpr
@@ -37,7 +39,7 @@ class BaseCrud(CoreCrud, ABC):
         if perm:
             return await self.get_list_with_perm(qi, perm=perm)
         else:
-            return await self.get_list(qi)
+            return await self.get_list(qi, _perm=perm)
 
     @staticmethod
     async def _solve_query(info: QueryInfo, perm: PermInfo):
@@ -81,18 +83,25 @@ class BaseCrud(CoreCrud, ABC):
 
     async def insert_many_with_perm(self, table: Type[RecordMapping], values_list: Iterable[ValuesToWrite],
                                     returning=False, *, perm: PermInfo) -> Union[IDList, List[QueryResultRow]]:
+        values_list_new = []
+
         if perm.is_check:
-            values_list_new = []
             avail = perm.role.get_perm_avail(table, A.CREATE)
 
-            for i in values_list:
-                data = {k: v for k, v in i.items() if k in avail}
-                if data:
-                    values_list_new.append(data)
-        else:
-            values_list_new = values_list
+        for i in values_list:
+            if perm.is_check:
+                for j in (i.keys() - avail):
+                    del i[j]
 
-        lst = await self.insert_many(table, values_list_new)
+            try:
+                i.bind(True, table=table)
+                if i:
+                    values_list_new.append(i)
+            except pydantic.ValidationError as e:
+                # TODO: 权限检查之后过不了检验的后面再处置
+                raise e
+
+        lst = await self.insert_many(table, values_list_new, _perm=perm)
 
         if returning:
             return await self.solve_returning(table, lst, perm=perm)
@@ -102,13 +111,22 @@ class BaseCrud(CoreCrud, ABC):
     async def update_with_perm(self, info: QueryInfo, values: ValuesToWrite, returning=False,
                                *, perm: PermInfo) -> Union[List[Any], List[QueryResultRow]]:
         if perm.is_check:
-            avail = perm.role.get_perm_avail(info.from_table, A.WRITE)
-            data = {k: v for k, v in values.items() if k in avail}
-        else:
-            data = values
+            avail = perm.role.get_perm_avail(info.from_table, A.UPDATE)
+
+            for j in (values.keys() - avail):
+                del values[j]
+
+        try:
+            values.bind(True, table=info.from_table)
+        except pydantic.ValidationError:
+            # TODO: 权限检查之后过不了检验的后面再处置
+            pass
+
+        if not values:
+            return []
 
         info = await self._solve_query(info, perm)
-        lst = await self.update(info, data)
+        lst = await self.update(info, values, _perm=perm)
 
         if returning:
             return await self.solve_returning(info.from_table, lst, info, perm=perm)
@@ -121,17 +139,17 @@ class BaseCrud(CoreCrud, ABC):
                 raise PermissionException('delete', info.from_table)
 
         info = await self._solve_query(info, perm)
-        return await self.delete(info)
+        return await self.delete(info, _perm=perm)
 
-    async def get_list_with_perm(self, info: QueryInfo, *, perm: PermInfo) -> List[QueryResultRow]:
+    async def get_list_with_perm(self, info: QueryInfo, with_count=False, *, perm: PermInfo) -> QueryResultRowList:
         info = await self._solve_query(info, perm)
-        return await self.get_list(info)
+        return await self.get_list(info, with_count, _perm=perm)
 
-    async def get_list_with_foreign_keys(self, info: QueryInfo, perm: PermInfo = None):
+    async def get_list_with_foreign_keys(self, info: QueryInfo, with_count=False, perm: PermInfo = None) -> QueryResultRowList:
         if perm is None:
             perm = PermInfo(False, None, None)
 
-        ret = await self.get_list_with_perm(info, perm=perm)
+        ret = await self.get_list_with_perm(info, with_count, perm=perm)
 
         async def solve(ret_lst, main_table, fk_queries, depth=0):
             if fk_queries is None:
