@@ -14,11 +14,11 @@ logger = logging.getLogger(__name__)
 
 class A(Enum):
     QUERY = 'query'
-    READ = 'read'
-    WRITE = 'write'
     CREATE = 'create'
+    READ = 'read'
+    UPDATE = 'update'
 
-    ALL = {QUERY, READ, WRITE, CREATE}
+    ALL = {QUERY, CREATE, READ, UPDATE}
 
 
 # PermissionDesc = Dict[Type['RecordMapping'], Dict[Union[Any, Literal['*', '|']], set]]
@@ -31,6 +31,9 @@ class RoleDefine:
     based_on: 'RoleDefine' = None
     match: Union[None, str] = None
 
+    def __hash__(self):
+        return id(self)
+
     def __post_init__(self):
         self.rebind()
 
